Re-exports
pub use rusqlite;
Structs
- Config
- Configuration object.
- Interrupt
Handler - Interruptible
Mapped Rows - Interruptible
Rows - Interruptible
Statement - Interruptible
Transaction - Manager
Managerfor creating and recycling SQLiteConnections.- Metrics
- Statistics regarding an object returned by the pool
- Object
Id - A unique identifier for an object within a pool.
- Pool
Config Poolconfiguration.- Statement
- Status
- The current pool status.
- Timeouts
- Timeouts when getting
Objects from aPool.
Enums
- Runtime
- Enumeration for picking a runtime implementation.
- Timeout
Type - Possible steps causing the timeout in an error returned by
Pool::get()method.
Traits
Functions
Type Aliases
- Config
Error - This error is returned if there is something wrong with the SQLite configuration.
- Connection
- Create
Pool Error - Hook
- Hook
Error - Pool
- Pool
Builder - Pool
Error - Rusqlite
Connection - Rusqlite
Pool - Transform
Fn