Crate sqlite_pool

Crate sqlite_pool 

Re-exports

pub use rusqlite;

Structs

Config
Configuration object.
InterruptHandler
InterruptibleMappedRows
InterruptibleRows
InterruptibleStatement
InterruptibleTransaction
Manager
Manager for creating and recycling SQLite Connections.
Metrics
Statistics regarding an object returned by the pool
ObjectId
A unique identifier for an object within a pool.
PoolConfig
Pool configuration.
Statement
Status
The current pool status.
Timeouts
Timeouts when getting Objects from a Pool.

Enums

Runtime
Enumeration for picking a runtime implementation.
TimeoutType
Possible steps causing the timeout in an error returned by Pool::get() method.

Traits

Committable
SqliteConn

Functions

noop_transform

Type Aliases

ConfigError
This error is returned if there is something wrong with the SQLite configuration.
Connection
CreatePoolError
Hook
HookError
Pool
PoolBuilder
PoolError
RusqliteConnection
RusqlitePool
TransformFn